# Examples for ZOSPy

Multiple examples are available for ZOSPy, showing various use-cases. Each example has its own (concise) README, providing some information about the analyses.

## Example overview

* **[Escudero-Sanz eye model](Escudero-Sanz%20eye%20model)** _(Sequential mode)_

  Shows how to create and analyze the eye model described in the paper _[Off-axis aberrations of a wide-angle schematic eye model](https://doi.org/10.1364/JOSAA.16.001881)_  by I. Escudero-Sanz, et al.

* **[Polarization Prism](Polarization%20Prism)** _(Sequential mode)_

  Shows how to perform and subsequently plot a polarization analysis in a prisim with total internal reflection.

* **[Ray trace Double Gauss](Ray%20trace%20Double%20Gauss)** _(Sequential mode)_

  Shows to perform and subsequently plot single ray traces and ray fan analyses in a Double Gauss lens.

* **[Retinal illumination in pseudophakic eyes](Retinal%20illumination%20in%20pseudophakic%20eyes%20with%20and%20without%20Negative%20Dysphotopsia)** _(Non-sequential mode)_

  Shows how to simulate the retinal illumination in non-sequential eye models as described in the paper _[Effect of anatomical differences and intraocular lens design on Negative
Dysphotopsia.](https://doi.org/10.1097/j.jcrs.0000000000001054)_  by L. van Vught, et al.

## Warranty and liability

The examples are provided 'as is'. There is no warranty and rights cannot be derived from them, as is also stated in the general license of this repository.